@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use strict;
 use warnings;
@@ -94,6 +94,8 @@ sub voicings {
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -104,7 +106,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -112,13 +114,7 @@ version 0.0100
 
   my $mcg = MIDI::Chord::Guitar->new;
 
-  my $chord = $mcg->chords->{C}[2]; # C major barre at position III
-  my $transformed = $mcg->transform($chord, 50); # Up to D
-
-  $chord = $mcg->chords->{C}[4]; # C major at position X
-  $transformed = $mcg->transform($chord, 50); # Down to D
-
-  $transformed = $mcg->to_chord('D3', 'm7b5', 2);
+  my $transformed = $mcg->transform('D3', 'dim7', 0);
 
   # MIDI:
   #$score->n('wn', @$transformed);
@@ -128,10 +124,6 @@ version 0.0100
 C<MIDI::Chord::Guitar> provides MIDI pitches for common chord voicings
 of an C<E A D G B E> tuned guitar.
 
-=head1 NAME
-
-MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
-
 =begin html
 
 Here is a handy diagram of MIDI pitch numbers laid out on a guitar neck:
@@ -177,6 +169,20 @@ guitar, a C note is represented by C<C3>, C<C4>, C<C5>, etc).
 
 Return all the voicings of a given B<chord_name>.
 
+=head1 SEE ALSO
+
+The F<t/01-methods.t> file in this distribution
+
+L<File::ShareDir>
+
+L<List::Util>
+
+L<Moo>
+
+L<Music::Note>
+
+L<Text::CSV_XS>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
@@ -189,15 +195,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
-
-L<File::ShareDir>
-
-L<List::Util>
-
-L<Moo>
-
-L<Text::CSV_XS>
-
-1;
